@@ -1,5 +1,6 @@
 var NAVTREEINDEX4 =
 {
+"structpst__entryid.html#a712b892005cccc699994fb0327204957":[0,0,16,0],
 "structpst__file.html":[0,0,17],
 "structpst__file.html#a0836103b6046b555d147bf44584102fa":[0,0,17,2],
 "structpst__file.html#a11624a5943c5e84269818d2842f5cb15":[0,0,17,9],
@@ -248,6 +249,5 @@ var NAVTREEINDEX4 =
 "structpst__item__email.html#a50a898611da08d2d40b4af3e8d23c439":[0,0,30,18],
 "structpst__item__email.html#a53a4e97e386814e4efed857f4b0e0f8d":[0,0,30,48],
 "structpst__item__email.html#a5402dd2bc4ff3320d04523d7d23dde0b":[0,0,30,25],
-"structpst__item__email.html#a546ef8423b20d572f6e296c60eac4e79":[0,0,30,13],
-"structpst__item__email.html#a5b8721cf9f59d694b6a40b594f03b89d":[0,0,30,6]
+"structpst__item__email.html#a546ef8423b20d572f6e296c60eac4e79":[0,0,30,13]
 };
