@@ -13,6 +13,11 @@
 #include "common.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
 // switch to maximal packing for all structures in the libpst interface
 // this is reverted at the end of this file
 #ifdef _MSC_VER
@@ -32,6 +37,7 @@
 #define PST_TYPE_TASK       12
 #define PST_TYPE_OTHER      13
 #define PST_TYPE_REPORT     14
+#define PST_TYPE_MAX        15
 
 // defines types of possible encryption
 #define PST_NO_ENCRYPT   0
@@ -64,7 +70,7 @@
 #define PST_APP_LABEL_ANNIVERSARY 9
 #define PST_APP_LABEL_PHONE_CALL  10
 
-// define type of recuring event
+// define type of recurring event
 #define PST_APP_RECUR_NONE        0
 #define PST_APP_RECUR_DAILY       1
 #define PST_APP_RECUR_WEEKLY      2
@@ -104,8 +110,8 @@ typedef struct pst_index_ll {
     uint64_t i_id;
     uint64_t offset;
     uint64_t size;
+    uint64_t inflated_size;
     int64_t  u1;
-    struct pst_index_ll *next;
 } pst_index_ll;
 
 
@@ -260,7 +266,7 @@ typedef struct pst_item_email {
     /** mapi element 0x1046, this seems to be the message-id of the rfc822 mail that is being returned */
     pst_string  return_path_address;
     /** mapi element 0x1007 PR_RTF_SYNC_BODY_COUNT,
-     *  a count of the *significant* charcters in the rtf body. Doesn't count
+     *  a count of the *significant* characters in the rtf body. Doesn't count
      *  whitespace and other ignorable characters. */
     int32_t     rtf_body_char_count;
     /** mapi element 0x1006 PR_RTF_SYNC_BODY_CRC */
@@ -606,6 +612,8 @@ typedef struct pst_item_attach {
     pst_string      filename2;
     /** mapi element 0x370e PR_ATTACH_MIME_TAG */
     pst_string      mimetype;
+    /** mapi element 0x3712 PR_ATTACH_CONTENT_ID  */
+    pst_string      content_id;
     /** mapi element 0x3701 PR_ATTACH_DATA_OBJ */
     pst_binary      data;
     /** only used if the attachment is by reference, in which case this is the id2 reference */
@@ -671,7 +679,7 @@ typedef struct pst_recurrence {
      *  @li 3 has 5 parameters
      */
     uint32_t    sub_type;
-    /** must be contiguous, not an array to make python interface easier */
+    /** must be contiguous, not an array to make Python interface easier */
     uint32_t    parm1;
     uint32_t    parm2;
     uint32_t    parm3;
@@ -691,7 +699,7 @@ typedef struct pst_recurrence {
     uint32_t    dayofmonth;
     /** month of year for yearly recurrences */
     uint32_t    monthofyear;
-    /** occurence of day for 2nd Tuesday of month, in which case position is 2 */
+    /** occurrence of day for 2nd Tuesday of month, in which case position is 2 */
     uint32_t    position;
     /** number of occurrences, even if recurrence terminates based on date */
     uint32_t    count;
@@ -854,9 +862,9 @@ typedef struct pst_item {
 
 /** Linked list of extended attributes.
  *  This is used to convert mapi_id values in the pst file into
- *  cannonical mapi_id values to be used in this code. This list
+ *  canonical mapi_id values to be used in this code. This list
  *  is kept in sorted order, where the key is the 'map' field.
- *  Some mapi_id values are converted to cannonical mapi_id values
+ *  Some mapi_id values are converted to canonical mapi_id values
  *  (PST_MAP_ATTRIB), and others are converted to a string
  *  (PST_ATTRIB_HEADER).
  */
@@ -891,9 +899,10 @@ typedef struct pst_file {
     /** original file name when the file was opened */
     char*   fname;
     /** default character set for items without one */
-    char*   charset;
-    /** the head and tail of the linked list of index structures */
-    pst_index_ll *i_head, *i_tail;
+    const char*   charset;
+    /** the array of index structures */
+    pst_index_ll *i_table;
+    size_t i_count, i_capacity;
     /** the head and tail of the top level of the descriptor tree */
     pst_desc_tree  *d_head, *d_tail;
     /** the head of the extended attributes linked list */
@@ -904,7 +913,8 @@ typedef struct pst_file {
     pst_block_recorder *block_head;
 
     /** @li 0 is 32-bit pst file, pre Outlook 2003;
-     *  @li 1 is 64-bit pst file, Outlook 2003 or later */
+     *  @li 1 is 64-bit pst file, Outlook 2003 or later;
+     *  @li 2 is 64-bit OST file, Outlook 2013 or later */
     int do_read64;
     /** file offset of the first b-tree node in the index tree */
     uint64_t index1;
@@ -918,7 +928,7 @@ typedef struct pst_file {
     uint64_t size;
     /** @li 0 PST_NO_ENCRYPT, none
      *  @li 1 PST_COMP_ENCRYPT, simple byte substitution cipher with fixed key
-     *  @li 2 PST_ENCRYPT, german enigma 3 rotor cipher with fixed key */
+     *  @li 2 PST_ENCRYPT, German enigma 3 rotor cipher with fixed key */
     unsigned char encryption;
     /** index type or file type
      *  @li 0x0e 32 bit pre Outlook 2003
@@ -1041,6 +1051,12 @@ pst_index_ll*   pst_getID(pst_file* pf, uint64_t i_id);
 size_t          pst_ff_getIDblock_dec(pst_file *pf, uint64_t i_id, char **buf);
 
 
+/** compare strings case-insensitive.
+ *  @return  -1 if a < b, 0 if a==b, 1 if a > b
+ */
+int pst_stricmp(char *a, char *b);
+
+
 /** fwrite with checking for null pointer.
  * @param ptr pointer to the buffer
  * @param size  size of each item
@@ -1094,7 +1110,7 @@ char*           pst_rfc2445_datetime_format_now(int buflen, char* result);
  * @param      item    pointer to the mapi item of interest
  * @param[in]  buflen  length of the output buffer
  * @param[out] result  pointer to output buffer, must be at least 30 bytes
- * @return default character set as a string useable by iconv()
+ * @return default character set as a string usable by iconv()
  */
 const char*     pst_default_charset(pst_item *item, int buflen, char* result);
 
@@ -1152,4 +1168,10 @@ void            pst_free_recurrence(pst_recurrence* r);
 
 
 
+#ifdef __cplusplus
+}
+#endif
+
+
+
 #endif
